import os
import imp
from mock import Mock

imp.load_source('ackg', os.path.join(os.path.dirname(__file__), '..', 'bin', 'ackg'))
import ackg

import unittest

def get_args(args=None):
    return ackg.get_arg_parser().parse_args(args)


class TestAckg(unittest.TestCase):


    def test_get_arg_parser(self):
        parser = ackg.get_arg_parser()


    def test_create_find_cmd(self):
        args = get_args()
        result = ackg.create_find_cmd(args)
        self.assertTrue(result.startswith('find'), result)
        self.assertTrue(' -type f ' in result, result)
        self.assertTrue(result.endswith('print0'), result)
        
    def test_create_defer_cmd(self):
        args = get_args()
        result = ackg.create_defer_cmd(args)
        self.assertTrue(result.startswith('xargs'), result)
        self.assertTrue(' -0 ' in result, result)
        self.assertTrue(' -n 100' in result, result)

    def test_create_grep_cmd(self):
        args = get_args(['foo'])
        result = ackg.create_grep_cmd(args)
        self.assertTrue(result.startswith('grep'), result)
        self.assertTrue(' --binary-files=without-match ' in result, result)
        self.assertTrue(' --color ' in result, result)
        self.assertTrue(' --ignore-case ' in result, result)
        self.assertTrue(' --line-number ' in result, result)
        self.assertTrue(' --with-filename ' in result, result)



from setuptools import setup

import imp


def get_version():
    ver_file = None
    try:
        imp.load_source('ackg', 'bin/ackg')
        import ackg
        version = ackg.VERSION
        return version
    finally:
        if ver_file is not None:
            ver_file.close()


setup(name='ackg',
      version=get_version(),
      scripts=["bin/ackg", "bin/group_grep_output"],
      install_requires=[],
      author="Thibault Kruse",
      author_email="thibault.kruse@gmx.de",
      url="https://github.com/tkruse/ackg",
      download_url="https://github.com/tkruse/ackg",
      keywords=["grep", "python", "linux"],
      classifiers=["Programming Language :: Python",
                   "License :: OSI Approved :: BSD License"],
      description="Script wrapping GNU find, xargs/parallel, grep to search code for pattern",
      long_description="""With ackg for Linux you can search folders
of your harddrive for source files containing a given pattern, similar
to grep.""",
      license="BSD")
